#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'generalopts.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALOPTS_H
#define UI_GENERALOPTS_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_GeneralOptsConfig
{
public:
    QVBoxLayout *verticalLayout;
    QCheckBox *kcfg_UseQuestionMarks;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GeneralOptsConfig)
    {
        if (GeneralOptsConfig->objectName().isEmpty())
            GeneralOptsConfig->setObjectName(QStringLiteral("GeneralOptsConfig"));
        GeneralOptsConfig->resize(316, 135);
        verticalLayout = new QVBoxLayout(GeneralOptsConfig);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        kcfg_UseQuestionMarks = new QCheckBox(GeneralOptsConfig);
        kcfg_UseQuestionMarks->setObjectName(QStringLiteral("kcfg_UseQuestionMarks"));

        verticalLayout->addWidget(kcfg_UseQuestionMarks);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(GeneralOptsConfig);

        QMetaObject::connectSlotsByName(GeneralOptsConfig);
    } // setupUi

    void retranslateUi(QWidget *GeneralOptsConfig)
    {
        kcfg_UseQuestionMarks->setText(tr2i18n("Use '?' marks", Q_NULLPTR));
        Q_UNUSED(GeneralOptsConfig);
    } // retranslateUi

};

namespace Ui {
    class GeneralOptsConfig: public Ui_GeneralOptsConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALOPTS_H

